@@ -250,6 +250,9 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                     if ('value' in s.set){
                         delete s.set.value; // do NOT change the value of anything.
                     }
+                    if ('modelSelection' in s.set){
+                        delete s.set.modelSelection; // do NOT change the modelSelection of anything.
+                    }
                     ['placeholder','tooltip','label'].forEach(function(key){
                          if (key in s.set){
                             s.set[key] = this.xtr(s.set[key]);
